@@ -9,6 +9,7 @@
 #define protected public
 
 #include <sbkpython.h>
+#include <sbkmodule.h>
 #include <sbkconverter.h>
 // Module Includes
 #include <pyside6_qtquick_python.h>
@@ -20,13 +21,21 @@
 
 // Bound library includes
 class QQuickStyle;
+
+// Type indices
+enum [[deprecated]] : int {
+    SBK_QQUICKSTYLE_IDX                                      = 0,
+    SBK_QTQUICKCONTROLS2_IDX_COUNT                           = 2,
+};
+
 // Type indices
 enum : int {
-    SBK_QQUICKSTYLE_IDX                                      = 0,
-    SBK_QtQuickControls2_IDX_COUNT                           = 1
+    SBK_QQuickStyle_IDX                                      = 0,
+    SBK_QtQuickControls2_IDX_COUNT                           = 1,
 };
+
 // This variable stores all Python types exported by this module.
-extern PyTypeObject **SbkPySide6_QtQuickControls2Types;
+extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtQuickControls2TypeStructs;
 
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtQuickControls2ModuleObject;
@@ -35,12 +44,21 @@ extern PyObject *SbkPySide6_QtQuickControls2ModuleObject;
 extern SbkConverter **SbkPySide6_QtQuickControls2TypeConverters;
 
 // Converter indices
-enum : int {
+enum [[deprecated]] : int {
     SBK_QTQUICKCONTROLS2_QLIST_INT_IDX                       = 0, // QList<int>
-    SBK_QTQUICKCONTROLS2_QLIST_QVARIANT_IDX                  = 1, // QList<QVariant>
-    SBK_QTQUICKCONTROLS2_QLIST_QSTRING_IDX                   = 2, // QList<QString>
-    SBK_QTQUICKCONTROLS2_QMAP_QSTRING_QVARIANT_IDX           = 3, // QMap<QString,QVariant>
-    SBK_QtQuickControls2_CONVERTERS_IDX_COUNT                = 4
+    SBK_QTQUICKCONTROLS2_QLIST_QVARIANT_IDX                  = 2, // QList<QVariant>
+    SBK_QTQUICKCONTROLS2_QLIST_QSTRING_IDX                   = 4, // QList<QString>
+    SBK_QTQUICKCONTROLS2_QMAP_QSTRING_QVARIANT_IDX           = 6, // QMap<QString,QVariant>
+    SBK_QTQUICKCONTROLS2_CONVERTERS_IDX_COUNT                = 8,
+};
+
+// Converter indices
+enum : int {
+    SBK_QtQuickControls2_QList_int_IDX                       = 0, // QList<int>
+    SBK_QtQuickControls2_QList_QVariant_IDX                  = 1, // QList<QVariant>
+    SBK_QtQuickControls2_QList_QString_IDX                   = 2, // QList<QString>
+    SBK_QtQuickControls2_QMap_QString_QVariant_IDX           = 3, // QMap<QString,QVariant>
+    SBK_QtQuickControls2_CONVERTERS_IDX_COUNT                = 4,
 };
 // Macros for type check
 
@@ -50,7 +68,7 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject *SbkType< ::QQuickStyle >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuickControls2Types[SBK_QQUICKSTYLE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQuickStyle >() { return Shiboken::Module::get(SbkPySide6_QtQuickControls2TypeStructs[SBK_QQuickStyle_IDX]); }
 
 } // namespace Shiboken
 
